[![Build Status](https://travis-ci.org/medialab/twitwi.svg)](https://travis-ci.org/medialab/twitwi)

# Twitwi

A collection of Twitter-related helper functions for python.

## Installation

You can install `twitwi` with pip with the following command:

```
pip install twitwi
```

## Usage

TODO...
